#!/usr/bin/python

################################################################
#                                                              #
# Blue Team Training Toolkit (BT3)                             #
# written by Juan J. Guelfo @ Encripto AS                      #
# post@encripto.no                                             #
#                                                              #
# Copyright 2013-2022 Encripto AS. All rights reserved.        #
#                                                              #
# BT3 is licensed under the FreeBSD license.                   #
# http://www.freebsd.org/copyright/freebsd-license.html        #
#                                                              #
################################################################


import os, zlib, zipfile
import libs.bt3api, libs.bt3in, libs.bt3out


# Common routine used by all modules for "download" command autocompletion
def autocomplete_download(api_credentials, text, line, material_type):
    autocomplete_list = []
    if len(api_credentials) == 2 and line.startswith("download"):
        try:
            json_results = libs.bt3api.get_material_list(api_credentials[0], api_credentials[1], material_type)
            if json_results and libs.bt3api.validate_json(json_results):
                parsed_results = libs.bt3api.parse_json(json_results)
                if parsed_results[-1]["Result"]:
                    del parsed_results[-1]
                    for result in parsed_results:
                        autocomplete_list.append(result["Name"])

        except Exception as e:
            print("")
            libs.bt3out.print_error("%s\n" % e)

    return [i for i in autocomplete_list if i.startswith(text)]


# Common routine used by all modules for "info" command autocompletion
def autocomplete_info(api_credentials, text, line, material_type, material_folder):
    autocomplete_list = []
    if line.startswith("info"):
        try:
            files = [f for f in os.listdir(material_folder) if os.path.isfile(os.path.join(material_folder, f))]
            files.sort()
            for material_file in files:
                if material_type.upper() in ["PROFILE"] and material_file.endswith(".py") and material_file not in ["__init__.py"]:
                    autocomplete_list.append(material_file)

                elif material_type.upper() in ["PCAP"] and (material_file.endswith(".pcap") or material_file.endswith(".cap")):
                    autocomplete_list.append(material_file)

                elif material_type.upper() in ["MOCKFILE"] and material_file.endswith(".mock"):
                    autocomplete_list.append(material_file)

        except Exception as e:
            print("")
            libs.bt3out.print_error("%s\n" % e)

    if len(api_credentials) == 2 and line.startswith("info"):
        try:
            json_results = libs.bt3api.get_material_list(api_credentials[0], api_credentials[1], material_type)
            if json_results and libs.bt3api.validate_json(json_results):
                parsed_results = libs.bt3api.parse_json(json_results)
                if parsed_results[-1]["Result"]:
                    del parsed_results[-1]
                    for result in parsed_results:
                        autocomplete_list.append(result["Name"])

        except Exception as e:
            print("")
            libs.bt3out.print_error("%s\n" % e)

    return [i for i in autocomplete_list if i.startswith(text)]


# Common routine used by all modules for "show" command autocompletion
def autocomplete_show(text, line, material_type):
    autocomplete_list = ["options", "interfaces", "downloads"]

    if material_type.upper() in ["PROFILE"]:
        autocomplete_list.append("profiles")

    elif material_type.upper() in ["PCAP"]:
        autocomplete_list.append("pcaps")

    elif material_type.upper() in ["MOCKFILE"]:
        autocomplete_list.append("mockfiles")

    if line.startswith("show profiles") or line.startswith("show pcaps") or line.startswith("show mockfiles"):
        autocomplete_list.append("cloud")
        autocomplete_list.append("disk")
        autocomplete_list.append("free")
        autocomplete_list.append("premium")

    return [i for i in autocomplete_list if i.startswith(text)]


# Common routine used by all modules for "download" command
def cmd_download(args, api_credentials, material_type, material_folder):
    print("")
    libs.bt3out.print_error("%s\n" % libs.bt3out.API_AUTHENTICATION)


def cmd_show_downloads(api_credentials, material_type):
    print("")
    libs.bt3out.print_error("%s\n" % libs.bt3out.API_AUTHENTICATION)
